@@ -8,8 +8,8 @@ import os
 import colemen_utils as c
 from flask import Flask,redirect,url_for,request,Blueprint
 
-import settings as _s
-import modules.Log as _log
+import apricity.settings as _s
+import apricity.modules.Log as _log
 
 main = None
 
@@ -19,16 +19,18 @@ main = None
 
 class Main:
     log:_log.Log = None
+    force_run:bool = False
     def __init__(self):
         self.settings = {}
         self.data = {}
         self.force_run = False
         self.app = Flask(__name__)
-        
+
     def prep(self):
         master_blueprint = Blueprint('master_blueprint', __name__)
-        master_blueprint.register_blueprint(_auth.auth_blueprint)
-        master_blueprint.register_blueprint(_home.home_blueprint)
+        # master_blueprint.register_blueprint(_services.auth_blueprint)
+
+        master_blueprint.register_blueprint(_services.home_blueprint)
         # master_blueprint.register_blueprint(_user.user_blueprint)
         # self.set_defaults()
 
@@ -58,8 +60,10 @@ main.log = _log.Log()
 
 
 
-import services.home.routes as _home
-import services.auth.routes as _auth
+# import apricity.services.home.routes as _home
+import apricity.services as _services
+
+# import apricity.services.auth.routes as _auth
 # import services.auth.routes as _auth
 
 
